@@ -10,7 +10,6 @@ import sys
 from time import strftime
 
 from andes.shared import NCPUS_PHYSICAL
-from ._version import get_versions
 
 from andes.main import config_logger, find_log_path
 from andes.routines import routine_cli
@@ -36,16 +35,12 @@ def create_parser():
              'or 40-ERROR.',
         type=int, default=20, choices=(1, 10, 20, 30, 40))
 
-    parser.add_argument(
-        '--version', help='show version info and exit', action='store_true')
-
     sub_parsers = parser.add_subparsers(dest='command', help='[run] run simulation routine; '
                                                              '[plot] plot results; '
                                                              '[doc] quick documentation; '
                                                              '[misc] misc. functions; '
                                                              '[prepare] prepare the numerical code; '
                                                              '[selftest] run self test; '
-                                                             '[demo] show demos.',
                                         )
 
     run = sub_parsers.add_parser('run')
@@ -146,6 +141,7 @@ def create_parser():
                       help='Set configuration option specificied by '
                       'NAME.FIELD=VALUE with no space. For example, "TDS.tf=2"',
                       type=str, default='', nargs='*')
+    misc.add_argument('--version', action='store_true', help='Display version information')
 
     prep = sub_parsers.add_parser('prepare', aliases=command_aliases['prepare'])
     prep_mode = prep.add_mutually_exclusive_group()
@@ -202,10 +198,6 @@ def main():
     parser = create_parser()
     args = parser.parse_args()
 
-    if args.version is True:
-        print(get_versions()['version'])
-        return
-
     # Set up logging
     config_logger(stream=True,
                   stream_level=args.verbose,
@@ -216,7 +208,7 @@ def main():
 
     module = importlib.import_module('andes.main')
 
-    if args.command in ('plot', 'doc'):
+    if args.command in ('plot', 'doc', 'misc'):
         pass
     elif args.command == 'run' and args.no_preamble is True:
         pass
