@@ -4,7 +4,7 @@ import numpy as np
 
 from andes.core import (Algeb, ConstService, ExtAlgeb, ExtParam, ExtService,
                         IdxParam, Lag, Limiter, Model, ModelData, NumParam,
-                        Piecewise, Switcher,)
+                        Piecewise, Switcher, IsEqual)
 from andes.core.block import (DeadBand1, GainLimiter, LagAWFreeze, LagFreeze,
                               LagRate, PITrackAWFreeze,)
 from andes.core.service import (ApplyFunc, DataSelect, ExtendedEvent, Replace,
@@ -357,10 +357,7 @@ class REECA1Model(Model):
                                     info='Initial power factor angle',
                                     )
         # flag devices with `p0`=0, which causes `tan(PF) = +inf`
-        self.zp0 = ConstService(v_str='Eq(p0, 0)',
-                                vtype=float,
-                                tex_name='z_{p0}',
-                                )
+        self.zp = IsEqual(self.p0, 0, cache=True)
 
         # --- Discrete components ---
         self.Vcmp = Limiter(u=self.v, lower=self.Vdip, upper=self.Vup, tex_name='V_{cmp}',
@@ -403,11 +400,11 @@ class REECA1Model(Model):
                           unit='p.u.',
                           )
 
-        # ignore `Qcpf` if `pfaref` is pi/2 by multiplying (1-zp0)
+        # ignore `Qcpf` if `pfaref` is pi/2 by multiplying (1-zp_z1)
         self.Qcpf = Algeb(tex_name='Q_{cpf}',
                           info='Q calculated from P and power factor',
                           v_str='q0',
-                          e_str='(1-zp0) * (S1_y * tan(pfaref) - Qcpf)',
+                          e_str='(1-zp_z1) * (S1_y * tan(pfaref) - Qcpf)',
                           diag_eps=True,
                           unit='p.u.',
                           )
