@@ -24,7 +24,8 @@ class BaseRoutine:
                               sparselib="linear sparse solver name",
                               linsolve="solve symbolic factorization each step (enable when KLU segfaults)",
                               )
-        self.config.add_extra("_alt", sparselib=("klu", "umfpack", "spsolve", "cupy"),
+        self.config.add_extra("_alt",
+                              sparselib=("klu", "umfpack", "spsolve", "cupy"),
                               linsolve=(0, 1),
                               )
 
